@@ -205,6 +205,10 @@ visTree <- function(object,
   stopifnot("character" %in% class(shapeY))
   
   if(!is.null(tooltipColumns)){
+    
+    if(class(tooltipColumns) %in% c("character", "factor")){
+      tooltipColumns <- which(tooltipColumns %in% colnames(data))
+    }
     stopifnot(class(tooltipColumns)[1] %in% c("numeric", "integer"))
     stopifnot(!is.null(data))
     stopifnot(max(tooltipColumns) <= ncol(data))
@@ -403,7 +407,11 @@ visTree <- function(object,
       popSpkl <- apply(dataOthr,2, function(X){
         Y <- sort(table(X))
         spl <- .addSparkLineOnlyJs(Y , type = "pie", labels = names(Y))
-        Y <- data.frame(Y)
+        if(length(Y) > 1){
+          Y <- data.frame(Y)
+        } else {
+          Y <- data.frame(X = names(Y), Freq = Y)
+        }
         Y$X <- ifelse(nchar(as.character(Y$X) ) > 9,
                       paste0(substr(Y$X, 1, 8), "..."), as.character(Y$X))
         modP <-  Y$X[length(Y$X)]
@@ -413,7 +421,7 @@ visTree <- function(object,
       namOrder <- lapply(dataOthr, function(X){
         names(sort(table(X)))
       })
-      labelComplete <-paste(labelComplete, sapply(nodesNames, function(Z){
+      labelComplete <- paste(labelComplete, sapply(nodesNames, function(Z){
         .giveLabelsFromDfChrInvisible(subsetRpart(object, dataOthr, Z),
                                       popSpkl, namOrder)} ) )
     }
@@ -874,9 +882,13 @@ visTreeEditor <- function(data, ...){
   nm <- names(df)
   re <- list()
   for(i in nm){
-    tbl <- table(df[,i])
+    tbl <- table(df[,i, drop = FALSE])
     tbl <- tbl[na.omit(match(namOrder[[i]], names(tbl)))]
-    tbl <- data.frame(tbl)
+    if(length(tbl) > 1){
+      tbl <- data.frame(tbl)
+    } else {
+      tbl <- data.frame(Var1 = names(tbl), Freq = tbl)
+    }
     newMod <- namOrder[[i]][!namOrder[[i]]%in%tbl$Var1]
     if(length(newMod) > 0){
       tbl <- rbind(tbl, data.frame(Var1 = newMod, Freq = 0))
@@ -887,14 +899,24 @@ visTreeEditor <- function(data, ...){
     
   }
   re <- unlist(re)
-  paste(paste("<br> <b>",names(re), ": </b><br>", popSpkl, "<br>",
-              re, collapse = ""))
+  paste(paste("<br> <b>",names(re), ": </b><br>", popSpkl, "<br>", re, collapse = ""))
 }
 
 
 
 
+#' @importFrom grDevices boxplot.stats
 .addSparkLineOnlyJs <- function(vect, min = NULL, max = NULL, type = "line", labels = NULL){
+  getboxplotValues <- function(x){
+    if(!all(is.na(x)) && length(x) >4){
+      x_box <- boxplot.stats(x)
+      x_out_range <- ifelse(length(x_box$out)>=2, range(x_box$out),NA)
+      return(sort(c(x_box$stats, x_out_range))) 
+    } else{
+      return(NA)
+    }
+  }
+  
   if(is.null(min))min <- min(vect)
   if(is.null(max))max <- max(vect)
   drun <- sample(LETTERS, 15, replace = TRUE)
@@ -907,15 +929,27 @@ visTreeEditor <- function(data, ...){
   }else{
     tltp <- NULL
   }
-  ttr <- paste0('
+  if(type != "box"){
+    ttr <- paste0('
+         $(function() {
+                  $(".inlinesparkline', drun,'").sparkline([',paste0(vect, collapse = ",") ,'], {
+                  type: "',type , '", chartRangeMin: ', min,', chartRangeMax: ', max,'
+                  , ', tltp, '
+                  }); 
+  });
+                  ')
+  } else {
+    vect <- getboxplotValues(vect)
+    ttr <- paste0('
          $(function() {
          $(".inlinesparkline', drun,'").sparkline([',paste0(vect, collapse = ",") ,'], {
-         type: "',type , '", chartRangeMin: ', min,', chartRangeMax: ', max,'
+         type: "',type , '", raw : true, chartRangeMin: ', min,', chartRangeMax: ', max,'
          , ', tltp, '
          }); 
          });
          ')
-  
+  }
+
   paste0('<div class="inlinesparkline', drun,'" style="display: inline-block;">&nbsp;</div>',
          '<script type="text/javascript">',
          ttr,
